package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsShipper;
import com.steerinfo.dil.service.impl.RmsShipperServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * RmsShipper RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-11-09 04:28
 * 类描述
 * 修订历史：
 * 日期：2021-11-09
 * 作者：HuJieHuan
 * 参考：
 * 描述：RmsShipper RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/rmsshipper")
public class RmsShipperController extends BaseRESTfulController {

    @Autowired
    RmsShipperServiceImpl rmsShipperService;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     * 展示托运人信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "apiId", value = "451", required = false, dataType = "BigDecimal"),
    })
    //@RequiresPermissions("rmsshipper:view")
    @PostMapping(value = "/getShipperList")
    public RESTfulResult getShipperList(@RequestBody(required = false) Map<String,Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        String con){


        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsShipperService.getShipperList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }

    /**
     * 添加托运人信息
     * @param rmsShipper
     * @return
     */
    @ApiOperation(value="创建", notes="根据RmsShipper对象创建")
    @ApiImplicitParam(name = "rmsShipper", value = "详细实体rmsShipper", required = true, dataType = "RmsShipper")
    //@RequiresPermissions("rmsshipper:create")
    @PostMapping(value = "/insertShipper")
    public RESTfulResult insertShipper(@RequestBody RmsShipper rmsShipper){
        int result= rmsShipperService.insertShipper(rmsShipper);
        if(result==-1){
            return failed();
        }
        return success(result);
    }

    /**
     * 更新托运人信息
     * @param rmsShipper
     * @return
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsShipper信息来更新详细信息")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short"),
        @ApiImplicitParam(name = "rmsShipper", value = "详细实体rmsShipper", required = true, dataType = "RmsShipper")
    })
    //@RequiresPermissions("rmsshipper:update")
    @PostMapping(value = "/updateShipper", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateShipper(@RequestBody RmsShipper rmsShipper){

        return success(rmsShipperService.updateShipper(rmsShipper));
    }

    /**
     * 根据id逻辑删除托运人
     * @param id
     * @return
     */
    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "Short")
    //@RequiresPermissions("rmsshipper:delete")
    @PostMapping(value = "/deleteShipper/{id}")//Short
    public RESTfulResult deleteShipper(@PathVariable("id") BigDecimal id){

      return success(rmsShipperService.deleteShipper(id));
    }

    /**根据id值详细获取人员信息
     *
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getShipperById/{id}")
    public RESTfulResult getShipperById(@PathVariable("id") BigDecimal id){
        List<Map<String, Object>> list= rmsShipperService.getShipperById(id);
        return success(list);
    }

    @ApiOperation(value="新增组织结构实绩")
    @PostMapping(value = "/addShipperResult")
    public RESTfulResult addShipperResult(@RequestBody(required = false) Map<String, Object> map){
        Integer i = null;
        try {
            i = rmsShipperService.addShipperResult(map);
            if(i != 1){
                return failed(i);
            }
        } catch (Exception e) {
            return failed();
        }
        return success(i);
    }

    @ApiOperation(value="修改组织结构实绩")
    @PostMapping(value = "/updateShipperResult")
    public RESTfulResult updateShipperResult(@RequestBody(required = false) Map<String, Object> map){
        Integer i = null;
        try {
            i = rmsShipperService.updateShipperResult(map);
            if(i != 1){
                return failed();
            }
        } catch (Exception e) {
            return failed();
        }
        return success(i);
    }

    @ApiOperation(value="删除组织结构实绩")
    @PostMapping(value = "/deleteShipperResult")
    public RESTfulResult deleteShipperResult(@RequestBody(required = false) Map<String, Object> map){
        Integer i = rmsShipperService.deleteShipperResult(map);
        if(i != 1){
            return failed(i);
        }
        return success(i);
    }
}
